# -*- coding: utf-8 -*-
from __future__ import print_function, unicode_literals

import logging

logger = logging.getLogger('weixin-open-api')
logger.setLevel(logging.DEBUG)
logger.addHandler(logging.StreamHandler())
